@@ -23,26 +23,28 @@ CONFIG_FILE_NAME = os.getenv('CONFIG_FILE_NAME', 'config.yml')
 CONFIG_FILE_PATH = os.path.join(CONFIG_DIR, CONFIG_FILE_NAME)
 
 
-def init_config(config_dictionary=None):
+def config_init(config=None):
     """
     Inicializace configurace. Pokud je konfigurace uložena v souboru, natáhne se z něj. Jinak se vytvoří a uloží.
 
-    :param config_dictionary: Slovník iniciální konfigurace
+    :param config: Slovník iniciální konfigurace
     :return: Uložená konfigurace
     """
+    out = {}
     if os.path.isfile(CONFIG_FILE_PATH):
         with open(CONFIG_FILE_PATH, "r") as yamlfile:
             out = yaml.load(yamlfile, Loader=yaml.FullLoader)
             logging.info('Configuration loaded')
-        return out
-    if config_dictionary is None:
-        logging.error('Config is empty')
-        config_dictionary = {}
-    store_config(config_dictionary)
-    return config_dictionary
+        if bool(out):
+            return out
+    if config is None:
+        logging.warning('Configuration is empty')
+        config = {}
+    config_store(config)
+    return config
 
 
-def store_config(config):
+def config_store(config):
     """
     Uložit konfiguraci
 
@@ -55,7 +57,7 @@ def store_config(config):
     return True
 
 
-def delete_config():
+def config_delete():
     """
     Odstraní soubor s konfigurací
 
@@ -69,6 +71,17 @@ def delete_config():
         return False
 
 
+def config_replace(config):
+    """
+    Nahradí konfigurační soubor novým obsahem
+
+    :param config:
+    :return:
+    """
+    config_delete()
+    return config_init(config=config)
+
+
 def url_safe(url):
     """
     Upraví URL, aby beobsahovalo nepovolené znaky
@@ -106,7 +119,7 @@ def unique_list(list1):
     return out
 
 
-def init_api_keys(agenda='main', amount=4):
+def api_keys_init(agenda='main', amount=4):
     """
     Vygeneruje klíče pro API
 
@@ -116,11 +129,11 @@ def init_api_keys(agenda='main', amount=4):
     """
     out = []
     for i in range(amount):
-        out.append(next_api_key('{} {}'.format(agenda, i + 1)))
+        out.append(api_key_next('{} {}'.format(agenda, i + 1)))
     return out
 
 
-def next_uuid(uuid_type=1):
+def uuid_next(uuid_type=1):
     """
     Vygeneruje UUID
 
@@ -134,7 +147,7 @@ def next_uuid(uuid_type=1):
     return out
 
 
-def next_api_key(name, length=16):
+def api_key_next(name, length=16):
     """
     Vygeneruje slovník API key {<API Key>: <name>}
 
@@ -142,11 +155,11 @@ def next_api_key(name, length=16):
     :param length:  Dělka API klíče
     :return:    Slovník {<API Key>: <name>}
     """
-    out = {generate_api_key(length=length): name}
+    out = {api_key_generate(length=length): name}
     return out
 
 
-def generate_api_key(length: int):
+def api_key_generate(length: int):
     """
     vygeneruje API klíč
 
@@ -182,4 +195,4 @@ def convert_hex_to_int(id_hex):
     return id_int
 
 
-CONFIG = init_config()
+CONFIG = config_init()
